#!/usr/bin/env python

import numpy as np
from matplotlib import animation
from matplotlib import pyplot as plt
from matplotlib.backends.qt_compat import QtWidgets
from matplotlib.widgets import Slider

π = np.pi

xy = np.linspace(0., 1., 2001)
xx, yy = np.meshgrid(xy, xy)


def modes(m, n):
    return np.cos(π * n * xx) * np.cos(π * m * yy)


fig, ax = plt.subplots(figsize=(16, 9))
manager = fig.canvas.manager
manager.window.findChild(QtWidgets.QToolBar).setVisible(False)
manager.set_window_title("Mody XY")
manager.full_screen_toggle()

psi = modes(1, 1)

img = ax.imshow(psi, extent=(0, 1, 0, 1), cmap='bwr', vmin=-1, vmax=1)
plt.plot([.5], [.5], 'o', color='k', markersize=10)

ax.set_aspect('equal')
ax.xaxis.set_major_locator(plt.MultipleLocator(1.00))
ax.yaxis.set_major_locator(plt.MultipleLocator(1.00))
ax.tick_params(axis='both', which='both', direction="in", left=True, right=True, top=True, bottom=True)
ax.xaxis.set_major_formatter(plt.NullFormatter())
ax.yaxis.set_major_formatter(plt.NullFormatter())

ax.set_xlim(0, 1)
ax.set_ylim(0, 1)

fig.tight_layout()

mmax = fig.add_axes([0.90, 0.10, 0.03, 0.8])
mnax = fig.add_axes([0.95, 0.10, 0.03, 0.8])

sst = {
    'track_color': '0.7',
    'color': '0.7',
    'initcolor': 'k',
}

m_slider = Slider(ax=mmax, label='$m$', orientation='vertical', valmin=0, valmax=12, valinit=1, valstep=1, **sst)
n_slider = Slider(ax=mnax, label='$n$', orientation='vertical', valmin=0, valmax=12, valinit=1, valstep=1, **sst)


def on_slider(val):
    global psi
    psi = modes(m_slider.val, n_slider.val)
    img.set_data(psi)
    fig.canvas.draw_idle()


m_slider.on_changed(on_slider)
n_slider.on_changed(on_slider)

plt.show()
